

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.List;

/**
 * <code>SimpleSearchEngine</code> builds an index of words given a list
 * of predefined URLs. It then will run word searches and URL similarity searches based 
 * on user's input. 
 */
public class SimpleSearchEngine {
	
	private WordIndex indexer;  // reference to a WordIndex instance

	/**
	 * Create a new SimpleSearchEngine
	 * @param index - An instance implementing the {@link WordIndex} interface.
	 */
	public SimpleSearchEngine(WordIndex index) {
		this.indexer = index;
	}
	
	/**
	 * Populate the index and run searches
	 */
	public void run() {
		indexURLs(indexer);
		doSearches(indexer);
	}

	private static void indexURLs(WordIndex indexer) {
		for (String strURL : strURLs) {
			System.out.println("Indexing \"" + strURL + "\" ...");
			indexer.index(HTMLTokenizer.getTokens(strURL), strURL);
		}
	}
	
	private static void doSearches(WordIndex indexer) {
		
		try {
			BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
			String str = null;
			do {
				System.out.print("> ");
				str = in.readLine().trim();
				if (str.equals("(exit)")) {
					break;
				}
				
				List<String> results;
				if (!str.startsWith("~")) {
					System.out.println("Searching for pages containing \"" + str + "\"...");
					results = indexer.search(str); // looking for pages containing the given word
				}
				else {
					String url = str.substring(1);
					System.out.println("Searching for pages similar to URL \"" + url + "\"...");
					results = indexer.findSimilarPages(url); // looking for similar pages
				}
				
				if (results == null  || results.size() == 0) {
					System.out.println("Unable to find relevant pages.");
				} else {
					for (int i = 0; i < results.size(); ++i) {
						System.out.println(i + 1 + ".\t" + results.get(i));
					}
				}
			} while (true);

		} catch (IOException e) { }
		
		System.out.println("Thank you for using SimpleSearch");
	}

	/**
	 * a list of urls we wish to index.
	 * feel free to add/remove urls from this list.
	 */
	static private String[] strURLs = {
		"http://en.wikipedia.org/wiki/Java_(programming_language)",
		"http://en.wikipedia.org/wiki/Java",
		"http://www.java.com/en/",
		"http://www.oracle.com",
		"http://www.java.net",
		"http://cnn.com",
		"http://bbc.com",
		"http://www.ynetnews.com",
		"http://haaretz.com",
		"http://www.nasa.gov",
		"http://www.space.com"
	};
}
